==> nextcloud-12.0.3.zip: nextcloud/apps/activity/l10n/hr.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivnosti",
    "An error occurred while loading activities" : "Greška pri učitavanju aktivnosti",
    "No activity yet" : "Nema aktivnosti",
    "Load more activities" : "Učitaj više aktivnosti",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Nije podržano!",
    "Press ⌘-C to copy." : "⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Ctrl-C za kopiranje.",
    "in {path}" : "u {path}",
    "This stream will show events like additions, changes & shares" : "Ova lista će prikazati događaje poput dodavanja, promjena i dijeljenja",
    "There are no events for this filter" : "Nema događaja koji odgovaraju ovom filteru",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "Personal activity feed for %s" : "Sažetak osobnih aktivnosti za %s",
    "Your feed URL is invalid" : "Nevažeći URL sažetka",
    "Your settings have been updated." : "Vaše su postavke ažurirane",
    "Settings have been updated." : "Postavke ažurirane.",
    "Mail" : "Pošta",
    "Stream" : "Strujanje",
    "All activities" : "Sve aktivnosti",
    "Hello %s" : "Poydrav %s",
    "Hello %s," : "Pozdrav %s,",
    "Activity notification" : "Notifikacija o aktivnosti",
    ", " : ", ",
    "%s and %s" : "%s i %s",
    "Activity" : "Aktivnost",
    "Activity feed" : "Sažetak aktivnosti",
    "Configure the default activity settings for new users." : "Definiraj osnovne postavke aktivnosti za nove korisnike.",
    "List your own actions in the stream" : "Prikaži vlastite aktivnosti na listi",
    "Notify about your own actions via email" : "Pošalji emailom obavijest o Vašim radnjama",
    "You need to set up your email address before you can receive notification emails." : "Da biste mogli primiti notifikaciju, morate najprije navesti svoju adresu e-pošte.",
    "Send emails:" : "Šaljite poruke e-pošte:",
    "Hourly" : "Svaki sat",
    "Daily" : "Svakodnevno",
    "Weekly" : "Svaki tjedan",
    "Settings" : "Postavke",
    "Enable RSS feed" : "Omogućite RSS sažetak događaja",
    "No more events to load" : "Nema više događaja za učitavanje",
    "Files" : "Datoteke"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-15.0.3.zip: nextcloud/apps/activity/l10n/hr.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivnost",
    "An error occurred while loading activities" : "Pogreška pri učitavanju aktivnosti",
    "No activity yet" : "Nema aktivnosti još",
    "Load more activities" : "Učitaj više aktivnosti",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Nije podržano!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restricted)",
    "in {path}" : "u {path}",
    "This stream will show events like additions, changes & shares" : "Ova lista će prikazati događaje poput dodavanja, promjena i dijeljenja",
    "There are no events for this filter" : "Nema događaja koji odgovaraju ovom filteru",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "Open file" : "Otvori datoteku",
    "Personal activity feed for %s" : "Sažetak osobnih aktivnosti za %s",
    "Your feed URL is invalid" : "Nevažeći URL sažetka",
    "Your settings have been updated." : "Vaše su postavke ažurirane.",
    "Settings have been updated." : "Postavke ažurirane.",
    "All activities" : "Sve aktivnosti",
    "\"remote user\"" : "\"udaljeni korisnik\"",
    "Hello %s" : "Bokić %s",
    "Hello %s," : "Bokić %s",
    ", " : ", ",
    "%s and %s" : "%s i %s",
    "Mail" : "Pošta",
    "Stream" : "Strujanje",
    "Activity feed" : "Sažetak aktivnosti",
    "Default settings" : "Zadane postavke",
    "Configure the default activity settings for new users." : "Definiraj osnovne postavke aktivnosti za nove korisnike.",
    "List your own actions in the stream" : "Prikaži vlastite aktivnosti na listi",
    "Notify about your own actions via email" : "Pošalji emailom obavijest o Vašim radnjama",
    "You need to set up your email address before you can receive notification emails." : "Da biste mogli primiti notifikaciju, morate najprije navesti svoju adresu e-pošte.",
    "Send emails:" : "Šaljite poruke e-pošte:",
    "As soon as possible" : "Čim prije moguće",
    "Hourly" : "Svaki sat",
    "Daily" : "Svakodnevno",
    "Weekly" : "Svaki tjedan",
    "Settings" : "Postavke",
    "Enable RSS feed" : "Omogućite sažetak događaja RSS",
    "RSS feed" : "Sažetak događaja RSS",
    "No more events to load" : "Nema više događaja za učitavanje",
    "Files" : "Datoteke",
    "Activities" : "Aktivnosti",
    "Home" : "Početna",
    "Activity notification" : "Notifikacija o aktivnosti"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
